@@ -1,7 +1,7 @@
-from . import GenericWorld, GenericWeb
+from . import TunicWorld, TunicWeb
 
 """
-Generic World Registration
+Tunic World Registration
 
 This file contains the metadata and class references for the tunic world.
 """
@@ -17,6 +17,6 @@ AUTHOR = author
 VERSION = version
 
 # Plugin entry points
-WORLD_CLASS = GenericWorld
-WEB_WORLD_CLASS = GenericWeb
+WORLD_CLASS = TunicWorld
+WEB_WORLD_CLASS = TunicWeb
 CLIENT_FUNCTION = None
